==> igniteui-webcomponents-core-3.2.0.tgz: package/esm5/lib/TextColumnDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { ColumnDescription } from "./ColumnDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var TextColumnDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(TextColumnDescription, _super);
    function TextColumnDescription() {
        var _this = _super.call(this) || this;
        _this.fj = null;
        _this.fh = null;
        _this.fe = null;
        _this.fi = null;
        _this.fk = null;
        return _this;
    }
    TextColumnDescription.prototype.get_type = function () {
        return "TextColumn";
    };
    Object.defineProperty(TextColumnDescription.prototype, "editorType", {
        get: function () {
            return this.fj;
        },
        set: function (a) {
            this.fj = a;
            this.e("EditorType");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextColumnDescription.prototype, "editorDataSourceRef", {
        get: function () {
            return this.fh;
        },
        set: function (a) {
            this.fh = a;
            this.e("EditorDataSourceRef");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextColumnDescription.prototype, "editorDataSource", {
        get: function () {
            return this.fe;
        },
        set: function (a) {
            this.fe = a;
            this.e("EditorDataSource");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextColumnDescription.prototype, "editorTextField", {
        get: function () {
            return this.fi;
        },
        set: function (a) {
            this.fi = a;
            this.e("EditorTextField");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextColumnDescription.prototype, "editorValueField", {
        get: function () {
            return this.fk;
        },
        set: function (a) {
            this.fk = a;
            this.e("EditorValueField");
        },
        enumerable: true,
        configurable: true
    });
    TextColumnDescription.$t = markType(TextColumnDescription, 'TextColumnDescription', ColumnDescription.$);
    TextColumnDescription.__canMarshalByValue1 = true;
    return TextColumnDescription;
}(ColumnDescription));
export { TextColumnDescription };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/TextColumnDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { DataGridColumnDescription } from "./DataGridColumnDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var TextColumnDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(TextColumnDescription, _super);
    function TextColumnDescription() {
        var _this = _super.call(this) || this;
        _this.fj = null;
        _this.fh = null;
        _this.fe = null;
        _this.fi = null;
        _this.fk = null;
        return _this;
    }
    TextColumnDescription.prototype.get_type = function () {
        return "TextColumn";
    };
    Object.defineProperty(TextColumnDescription.prototype, "editorType", {
        get: function () {
            return this.fj;
        },
        set: function (a) {
            this.fj = a;
            this.e("EditorType");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextColumnDescription.prototype, "editorDataSourceRef", {
        get: function () {
            return this.fh;
        },
        set: function (a) {
            this.fh = a;
            this.e("EditorDataSourceRef");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextColumnDescription.prototype, "editorDataSource", {
        get: function () {
            return this.fe;
        },
        set: function (a) {
            this.fe = a;
            this.e("EditorDataSource");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextColumnDescription.prototype, "editorTextField", {
        get: function () {
            return this.fi;
        },
        set: function (a) {
            this.fi = a;
            this.e("EditorTextField");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextColumnDescription.prototype, "editorValueField", {
        get: function () {
            return this.fk;
        },
        set: function (a) {
            this.fk = a;
            this.e("EditorValueField");
        },
        enumerable: true,
        configurable: true
    });
    TextColumnDescription.$t = markType(TextColumnDescription, 'TextColumnDescription', DataGridColumnDescription.$);
    TextColumnDescription.__canMarshalByValue1 = true;
    return TextColumnDescription;
}(DataGridColumnDescription));
export { TextColumnDescription };
